pub struct RepeatX {
pub shape: Tree,
pub radius: f64,
pub offset: f64,
}Expand description
Repeat a shape in the X axis
This uses the modulo operator, which may introduce discontinuities; shapes
should be designed to have the same value at x = ±radius.
Fields
shape: TreeShape to repeat
radius: f64Radius of the region to repeat
offset: f64X position about which to repeat