Module types

Module types 

Types used in shape construction

This module includes both GLSL-style Vec types and higher-level representations of modeling concepts (e.g. Axis).

We use dedicated types (instead of nalgebra types) because we must derive Facet on them, so are limited by the orphan rule.

Structs

Axis
Normalized 3D axis (of length 1)
Plane
Unoriented plane in 3D space, specified as an axis + offset
Vec2
2D position
Vec3
3D position
Vec4
4D position (xyzw)
WrongType
Error type for conversions

Enums

AxisError
Error type for axis construction
Type
Auto-generated discriminant enum variants
Value
Enumeration representing all types that can be used in shapes

Functions

eval_default_fn
Evaluates a default builder function, returning a value