pub enum AxisError {
TooShort(f64),
TooLong(f64),
BadLength,
}Expand description
Error type for axis construction
Variants
TooShort(f64)
Vector is too short to convert to an axis
TooLong(f64)
Vector is too long to convert to an axis
BadLength
Could not normalize vector due to an invalid length