pub enum Type {
Float,
Vec2,
Vec3,
Vec4,
Axis,
Plane,
Tree,
VecTree,
}Expand description
Auto-generated discriminant enum variants
Variants
Implementations
Sourceimpl Type
impl Type
Sourcepub unsafe fn build_from_default_fn(&self, f: DefaultSource) -> Value
pub unsafe fn build_from_default_fn(&self, f: DefaultSource) -> Value
Executes a default builder function for the given type
Safety
f must be a builder for the type associated with this tag